@@ -1,5 +1,5 @@
 # Module: autosentiment
-# Author: Sazin Reshed Samin <sazinsamin50@gmail.com>
+# Author: Sazin Reshed Samin, Email :  <sazinsamin50@gmail.com>
 # License: MIT
 
 
@@ -10,15 +10,13 @@ from math import floor,ceil
 
 
 
-
-"""Pie chart"""
+#Pie chart
 def pie(data):
     comment = pd.DataFrame(data)
     comment = pd.DataFrame(data)
     comment = data.dropna()
     comment = pd.DataFrame(comment)
     comment.reset_index()
-    comment.shape
 
     # Comment columns name
     name = list(comment.columns)
@@ -49,19 +47,17 @@ def pie(data):
     centre_circle = plt.Circle((0, 0), 0.70, fc='white');
     fig = plt.gcf();
     fig.gca().add_artist(centre_circle);
-    plt.title('Comment sentiment percentage(%)', bbox={'facecolor': '0.8', 'pad': 5});
+    plt.title('Sentiment type percentage(%)', bbox={'facecolor': '0.8', 'pad': 5});
 
     return pie_chart
 
-
-"""Sentiment type numbers"""
+#Sentiment type numbers
 def number(data):
     comment = pd.DataFrame(data)
     comment = pd.DataFrame(data)
     comment = data.dropna()
     comment = pd.DataFrame(comment)
     comment.reset_index()
-    comment.shape
 
     # Comment columns name
     name = list(comment.columns)
@@ -82,19 +78,19 @@ def number(data):
     negetive = (comment['sentiment'] < 0).sum()
     neutral = (comment['sentiment'] == 0).sum()
 
-    sentiment_list = {'postive': positive, 'negetive': negetive, 'neutral': neutral}
+    sentiment_list={'positive  ' : positive,'negetive':negetive,'neutral':neutral}
+
+
     return sentiment_list
 
 
-
-"""Sentiment type percentage"""
+#Sentiment type percentage
 def percentage(data):
     comment = pd.DataFrame(data)
     comment = pd.DataFrame(data)
     comment = data.dropna()
     comment = pd.DataFrame(comment)
     comment.reset_index()
-    comment.shape
 
     # Comment columns name
     name = list(comment.columns)
@@ -118,22 +114,21 @@ def percentage(data):
     total = positive + negetive + neutral;
 
     pop = (positive / total) * 100;
-    nep = (negetive / total) * 100;
+    neg = (negetive / total) * 100;
     nup = (neutral / total) * 100;
 
     pop=round(pop,2)
-    nep=round(nep,2)
-    nup=round(nep,2)
+    neg=round(neg,2)
+    nup=round(nup,2)
 
+    sentiment_list=("Positve : {} %, Negetive {} %, Neutral : {} %".format(pop,neg,nup))
 
-    sentiment_list = {'postive {:%d%}}': format(pop), 'negetive': nep, 'neutral': nup}
 
     return sentiment_list
 
 
 
-
-"""The ternary analysis"""
+#The ternary analysis
 
 def analysis_ternary(data):
     comment = pd.DataFrame(data)
@@ -160,3 +155,4 @@ def analysis_ternary(data):
 
 
 
+
